Learn R Programming

invitroTKstats (version 0.0.14)

.check_char_cols: Check the character columns are correctly of character class.

Description

Check the character columns are correctly of character class.

Usage

.check_char_cols(data, char.cols)

Arguments

data

Data frame to check.

char.cols

Column names that should be of the character class.