Learn R Programming

invitroTKstats (version 0.0.14)

.check_std_colnames_in_data: Check the standard column names are in the data.

Description

Check the standard column names are in the data.

Usage

.check_std_colnames_in_data(data, std.colnames, data.name = NULL)

Arguments

data

Data frame to check.

std.colnames

Vector of character strings with standard column names to check for in the data.

data.name

Name of the data object passed to the standard column names check function. (Defaults to NULL.)