| Heaviside | R Documentation |
Evaluate the Heaviside function with threshold indicating the discontinuity.
If elements in x are greater than or equal to threshold, returns 1.
Otherwise, returns 0.
Heaviside(x, threshold = 0)
x |
(Numeric) A numeric vector. |
threshold |
(Numeric) A threshold value used to compare to elements in |
A vector of 1 and 0. 1 indicates the element in x is larger or equal to the threshold.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.