powered by
Common column names across the various in vitro assays used for collecting in vitro toxicokinetic parameters.
L1.common.cols
A named character vector containing the default/standard column names across HTTK assays, where the element names are the corresponding L1 arguments.