Builds a list of arguments required for JAGS from subset of level-2 data frame. The list is used as an argument to JAGS during level-4 processing.
build_mydata_clint(
this.cvt,
this.data,
decrease.prob,
saturate.prob,
degrade.prob
)A named list to be passed into the Bayesian model.
(Data Frame) Subset of data containing all "Cvst" sample observations of one test compound.
(Data Frame) Subset of data containing all observations of one test compound.
(Numeric) Prior probability that a chemical will decrease in the assay.
(Numeric) Prior probability that a chemicals rate of metabolism will decrease between 1 and 10 uM.
(Numeric) Prior probability that a chemical will be unstable (that is, degrade abiotically) in the assay.