Learn R Programming

invitroTKstats (version 0.0.14)

build_mydata_fup_red: Build Data Object for Fup RED Bayesian Model

Description

Builds a list of arguments required for JAGS from subset of level-2 data frame. The list is used as an argument to JAGS during level-4 processing.

Usage

build_mydata_fup_red(this.data, Physiological.Protein.Conc)

Value

A named list to be passed into the Bayesian model.

Arguments

this.data

(Data Frame) Subset of data containing all observations of one test compound.

Physiological.Protein.Conc

(Numeric) The assumed physiological protein concentration for plasma protein binding calculations.