A subset of tandem mass spectrometry (MS/MS) measurements of Caco-2 assay-specific data honda2025impactinvitroTKstats. This subset contains samples for 3 test analytes/compounds.
caco2_L2A level-2 data.frame with 48 rows and 29 variables:
Lab.Sample.NameSample name as described in the laboratory
DateDate MS/MS assay data acquired from instrument
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of Caco-2 sample
DirectionDirection of the Caco-2 permeability experiment
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration -- usually the date
Biological.ReplicatesIdentifier for measurements of multiple samples with the same analyte
Technical.ReplicatesIdentifier for repeated measurements of one sample of a compound
Test.Compound.ConcMeasured concentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcExpected initial concentration of chemical added to donor side (uM)
TimeTime when sample was measured (h)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
AreaPeak area of analyte (target compound)
Membrane.AreaThe area of the Caco-2 monolayer.
Vol.DonorThe media volume (in cm^3) of the donor portion of the Caco-2 experimental well
Vol.ReceiverThe media volume (in cm^3) of the receiver portion of the Caco-2 experimental well
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifing analyte peak (for example, retention time)
NoteAdditional information
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame)
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other causes the data to be ignored.)
honda2025impactinvitroTKstats