| caco2_L3 | R Documentation |
A subset of tandem mass spectrometry (MS/MS) measurements of Caco-2 assay-specific data \insertCitehonda2025impactinvitroTKstats. This subset contains samples for 3 test analytes/compounds.
caco2_L3
A level-3 data.frame with 3 rows and 20 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
TimeTime when sample was measured (h)
Membrane.AreaThe area of the Caco-2 monolayer
CalibrationIdentifier for mass spectrometry calibration – usually the date
C0_A2BInitial concentration in the apical side
dQdt_A2BRate of permeation from the apical to the basolateral side
Papp_A2BApparent membrane permeability from the apical to the basolateral side
Frec_A2B.vecFraction of the initial compound in the apical side recovered in the basolateral side (collapsed numeric vector, values for replicates separated by a "|")
Frec_A2B.meanMean of fraction recovered values in the apical to basolateral direction
Recovery_Class_A2B.vecRecovery classification of fraction recovered values in the apical to basolateral direction (collapsed character vector, values for replicates separated by a "|")
Recovery_Class_A2B.meanRecovery classification of mean fraction recovered in the apical to basolateral direction
C0_B2AInitial concentration in the basolateral side
dQdt_B2ARate of permeation from the basolateral to the apical side
Papp_B2AApparent membrane permeability from the basolateral to the apical side
Frec_B2A.vecFraction of the initial compound in the basolateral side recovered in the apical side (collapsed numeric vector, values for replicates separated by a "|")
Frec_B2A.meanMean of fraction recovered values in the basolateral to apical direction
Recovery_Class_B2A.vecRecovery classification of fraction recovered values in the basolateral to apical direction (collapsed character vector, values for replicates separated by a "|")
Recovery_Class_B2A.meanRecovery classification of mean fraction recovered in the basolateral to apical direction
ReffluxEfflux ratio
honda2025impactinvitroTKstats
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.