## Example 1: loading level-2 using data.in and export all files to the user's
## temporary directory
if (FALSE) {
level2 <- invitroTKstats::clint_L2
# JAGS.PATH should be changed to user's specific computer file path to JAGS software.
# findJAGS() from runjags package is a handy function to find JAGS path automatically.
# In certain circumstances or cases, one may need to provide the absolute path to JAGS.
path.to.JAGS <- runjags::findJAGS()
level4 <- calc_clint(FILENAME = "Example1",
data.in = level2,
NUM.CORES=2,
JAGS.PATH=path.to.JAGS)
}
## Example 2: importing level-2 from a .tsv file and export all files to same
## location as INPUT.DIR
if (FALSE) {
# Refer to sample_verification help file for how to export level-2 data to a directory.
# JAGS.PATH should be changed to user's specific computer file path to JAGS software.
# findJAGS() from runjags package is a handy function to find JAGS path automatically.
# In certain circumstances or cases, one may need to provide the absolute path to JAGS.
# Will need to replace FILENAME and INPUT.DIR with name prefix and location of level-2 'tsv'.
path.to.JAGS <- runjags::findJAGS()
level4 <- calc_clint(# e.g. replace with "Examples" from "Examples-Clint-Level2.tsv"
FILENAME="",
NUM.CORES=2,
JAGS.PATH=path.to.JAGS,
INPUT.DIR = "")
}
Run the code above in your browser using DataLab