| clint_L0 | R Documentation |
Mass Spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and poly-fluorinated alkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore \insertCitesmeltz2023plasmainvitroTKstats. This data set is a subset of experimental data containing samples for 3 test analytes/compounds.
clint_L0
A level-0 data.frame with 247 rows and 16 variables:
CompoundName of the test analyte/compound
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard - CCD)
Lab.Compound.IDCompound as described in the laboratory
DateDate the sample was added to the MS analyzer
SampleSample description used in the laboratory
TypeType of Clint sample
Compound.ConcExpected (or nominal) concentration of analyte (for calibration curve)
Peak.AreaPeak area of analyte (target compound)
ISTD.Peak.AreaPeak area of internal standard (ISTD) compound (pixels)
ISTD.NameName of the internal standard (ISTD) analyte/compound
Analysis.ParamsColumn contains the retention time
Level0.FileName of the laboratory data file from which the level-0 sample data was extracted
Level0.SheetName of the Excel workbook 'sheet' from which the level-0 sample data was extracted
Sample.TextAdditional notes on the sample
TimeTime when the sample was measured - in hours (h)
Dilution.FactorNumber of times the sample was diluted
shibata2002predictioninvitroTKstats
\insertRefsmeltz2023plasmainvitroTKstats
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.