Mass Spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and poly-fluorinated alkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This data set is a subset of experimental data containing samples for 3 test analytes/compounds.
clint_L2A level-2 data.frame with 229 rows and 25 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate the sample was added to the MS analyzer
Compound.NameName of the test analyte/compound
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard - CCD)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of Clint sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration -- usually the date
ISTD.NameName of the internal standard (ISTD) analyte/compound
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifing analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of the laboratory data file from which the level-0 sample data was extracted
Level0.SheetName of the Excel workbook 'sheet' from which the level-0 sample data was extracted
TimeTime when the sample was measured - in hours (h)
Test.Compound.ConcMeasured concentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcExpected initial concentration of chemical added to well (uM)
Hep.DensityThe density (units of millions of hepatocytes per mL) hepatocytes in the in vitro incubation
Biological.ReplicatesIdentifier for measurements of multiple samples with the same analyte
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
shibata2002predictioninvitroTKstats
smeltz2023plasmainvitroTKstats