The arguments given to JAGS for the tested compound during level-4 processing of mass spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and poly-fluorinated alkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This list is overwritten for each tested compound. Therefore, only contains arguments given to JAGS for the last tested compound.
clint_PREJAGSA named list with 26 elements:
obsResponse of the "Cvst" sample types for the tested compound
Test.Nominal.ConcUnique Test.Nominal.Conc values (expected initial concentration) of "Cvst" sample types
Num.calUnique number of Calibration values
Num.obsNumber of Response of the "Cvst" sample types for the tested compound
obs.concIndices of the Test.Nominal.Conc values that corresponds to the "Cvst" sample types' Test.Nominal.Conc
obs.timeTime of the "Cvst" sample types for the tested compound
obs.calIndices of the unique "Cvst" Calibration values that corresponds to the "Cvst" sample types' Calibration
obs.Dilution.FactorDilution Factor of the "Cvst" sample types for the tested compound (number of times the sample was diluted)
Num.blank.obsNumber of "Blank" sample types for the tested compound
Blank.obsResponse of the "Blank" sample types for the tested compound
Blank.calIndices of the unique "Blank" Calibration values that corresponds to the "Blank" sample types' Calibration
Blank.Dilution.FactorDilution Factor of the "Blank" sample types for the tested compound (number of times the sample was diluted)
Num.ccNumber of "CC" sample types with non-NA Test.Compound.Conc values for the tested compound
cc.obs.concTest.Compound.Conc (non-NA) of the "CC" sample types for the tested compound
cc.obsResponse of the "CC" sample types with non-NA Test.Compound.Conc for the tested compound
cc.obs.calIndices of the unique "CC" Calibration values that corresponds to the "CC" sample types' Calibration
cc.obs.Dilution.FactorDilution Factor of the "CC" sample types (number of times the sample was diluted) with non-NA Test.Compound.Conc for the tested compound
Num.abio.obsNumber of "Inactive" samples types for the tested compound
abio.obsResponse of the "Inactive" sample types for the tested compound
abio.obs.concIndices of the Test.Nominal.Conc values that corresponds to the "Inactive" sample types' Test.Nominal.Conc
abio.obs.timeTime of the "Inactive" sample types for the tested compound
abio.obs.calIndices of the unique "Inactive" Calibration values that corresponds to the "Inactive" sample types' Calibration
abio.obs.Dilution.FactorDilution Factor of the "Inactive" sample types for the tested compound (number of times the sample was diluted)
DECREASE.PROBPrior probability that a chemical will decrease in the assay. (Defaults to 0.5.)
SATURATE.PROBPrior probability that a chemicals rate of metabolism will decrease between 1 and 10 uM. (Defaults to 0.25.)
DEGRADE.PROBPrior probability that a chemical will be unstable (degrade abiotically) in the assay. (Defaults to 0.05.)
shibata2002predictioninvitroTKstats
smeltz2023plasmainvitroTKstats