This function extracts data from a Microsoft Excel file containing many columns corresponding to different types of data.
extract_level1_fup_uc(
data.set,
chem.name,
area.col.num,
ISTD.name,
ISTD.offset = 2,
analysis.method = "GC",
instrument = "Something or Other 3000",
inst.param.offset = -3,
conc.offset = -2,
area.base = "Area...",
inst.param.base = "RT...",
conc.base = "Final Conc....",
id.cols = c("Name", "Data File", "Acq. Date-Time"),
type.indicator.col = "Name",
AF.type.str = "AF",
T1.type.str = "T1",
T5.type.str = "T5",
CC.type.str = "CC"
)A data.frame in standardized "level1" format
(Data Frame) A data frame containing a sheet of data for conversion.
(Character) A string giving the lab name of the chemical analyzed. The value provided is used for all rows in the output data frame.
(Numeric) An integer indicating which column of data.set contains the MS feature area for the chemical.
(Character) A string indicating the internal standard used. The value provided is used for all rows in the output data frame.
(Numeric) An integer indicating how many columns difference there is between the chemical of study MS area and the ISTD MS area. (Defaults to 2.)
(Character) A string describing the chemical analysis method. The value provided is used for all rows in the output data frame. (Defaults to "GC", that is gas chromatography.)
(Character) A string describing the instrument used for chemical analysis. The value provided is used for all rows in the output data frame. (Defaults to "Something or Other 3000".)
(Numeric) An integer indicating the difference in the number of columns between the MS peak area and the column giving the instrument parameters. (Defaults to -3.)
(Numeric) An integer indicating the difference in the number of columns between the MS peak area and the column giving the intended concentration for calibration curves. (Defaults to -2.)
(Character) A character string used for forming the name of MS feature area column names (used for both test chemical and ISTD). (Defaults to "Area...".)
(Character) A character string used for forming the name of the chemical analysis instrument parameter column name. (Defaults to "RT...".)
(Character) A character string used for forming the name of the calibration curve intended concentration column name. (Defaults to "Final Conc....".)
(Character Vector) A vector of character strings used for identifying each sample. (Defaults to c("Name", "Data File", "Type", "Acq. Date-Time").)
(Character) A character string indicating which column of data.set contains the type of observation. (Defaults to "Name".)
(Character) String used to annotate observation of this type: Aqueous Fraction. (Defaults to "AF".)
(Character) String used to annotate observation of this type: Whole Plasma T1h Sample. (Defaults to "T1".)
(Character) String used to annotate observation of this type: Whole Plasma T5h Sample. (Defaults to "T5".)
(Character) String used to annotate observation of this type: Calibration Curve. (Defaults to "CC".)
John Wambaugh
The data frame of observations should be annotated according to of these types:
| Calibration Curve | CC | Ultracentrifugation Aqueous Fraction | AF | Whole Plasma T1h Sample |
redgrave1975separationinvitroTKstats