The arguments given to JAGS for the tested compound during level-4 processing of mass spectrometry measurements of plasma protein binding (PPB) via rapid equilibrium dialysis (RED) for per- and poly-fluorinated alkyl substance (PFAS) samples. Experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This list is overwritten for each tested compound. Therefore, only contains arguments given to JAGS for the last tested compound.
fup_red_PREJAGSA named list with 33 elements:
Test.Nominal.ConcUnique Test.Nominal.Conc values (expected initial concentration) for the tested compound
Num.calUnique number of Calibration values for the tested compound
Physiological.Protein.ConcThe assumed physiological protein concentration for plasma protein binding calculations. (Defaults to 70/(66.5*1000)*1000000. According to berg2011pathology;textualinvitroTKstats: 60-80 mg/mL, albumin is 66.5 kDa, assume all protein is albumin to estimate default in uM.)
Assay.Protein.PerecentPercent.Physiologic.Plasma values for each "Plasma" sample type replicate group
Num.Plasma.Blank.obsNumber of "Plasma.Blank" sample types for the tested compound
Plasma.Blank.obsResponse of the "Plasma.Blank" sample types for the tested compound
Plasma.Blank.calIndices of the unique Calibration values that corresponds to the "Plasma.Blank" sample types' Calibration for the tested compound
Plasma.Blank.dfUnique Dilution Factor of the "Plasma.Blank" sample types for the tested compound
Plasma.Blank.repInteger representing "Plasma.Blank" replicate group for the tested compound
Num.NoPlasma.Blank.obsNumber of "NoPlasma.Blank" sample types for the tested compound
NoPlasma.Blank.obsResponse of the "NoPlasma.Blank" sample types for the tested compound
NoPlasma.Blank.calIndices of the unique Calibration values that corresponds to the "NoPlasma.Blank" sample types' Calibration for the tested compound
NoPlasma.Blank.dfUnique Dilution Factor of the "NoPlasma.Blank" sample types for the tested compound
Num.CC.obsNumber of "CC" sample types with non-NA Test.Compound.Conc values for the tested compound
CC.concTest.Compound.Conc (non-NA) of the "CC" sample types for the tested compound
CC.obsResponse of the "CC" sample types with non-NA Test.Compound.Conc for the tested compound
CC.calIndices of the unique Calibration values that corresponds to the "CC" sample types' Calibration for the tested compound
CC.dfUnique Dilution Factor of the "NoPlasma.Blank" sample types for the tested compound
Num.T0.obsNumber of "T0" sample types for the tested compound
T0.obsResponse of the "T0" sample types for the tested compound
T0.calIndices of the unique Calibration values that corresponds to the "T0" sample types' Calibration for the tested compound
T0.dfUnique Dilution Factor of the "T0" sample types for the tested compound
Num.repUnique number of (Calibration + Technical.Replicates) combinations for "PBS" and "Plasma" sample types for the tested compound
Num.PBS.obsNumber of "PBS" sample types for the tested compound
PBS.obsResponse of the "PBS" sample types for the tested compound
PBS.calIndices of the unique Calibration values that corresponds to the "PBS" sample types' Calibration for the tested compound
PBS.dfUnique Dilution Factor of the "PBS" sample types for the tested compound
PBS.repInteger representing "PBS" replicate group for the tested compound
Num.Plasma.obsNumber of "Plasma" sample types for the tested compound
Plasma.obsResponse of the "Plasma" sample types for the tested compound
Plasma.calIndices of the unique Calibration values that corresponds to the "Plasma" sample types' Calibration for the tested compound
Plasma.dfUnique Dilution Factor of the "Plasma" sample types for the tested compound
Plasma.repInteger representing "Plasma" replicate group for the tested compound
waters2008validationinvitroTKstats
smeltz2023plasmainvitroTKstats