Learn R Programming

invitroTKstats (version 0.0.14)

fup_red_cheminfo: Fup RED Chemical Information Example Data set

Description

The chemical ID mapping information from mass spectrometry measurements of plasma protein binding (PPB) via rapid equilibrium dialysis (RED) for per- and poly-fluorinated alkyl substance (PFAS) samples. Experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This data set contains 26 unique compounds/chemicals.

Usage

fup_red_cheminfo

Arguments

Format

A chemical info data.frame with 26 rows and 4 variables:

DTXSID

DSSTox Substance Identifier (CompTox Chemicals Dashboard - CCD)

NAME (Abbreviation)

Name of the test analyte/compound and abbreviation used by the lab as the compound ID

Compound

Name of the test analyte/compound

Chem.Lab.ID

Abbreviation of the test analyte/compound as described in the laboratory

References

waters2008validationinvitroTKstats

smeltz2023plasmainvitroTKstats