Mass Spectrometry measurements of plasma protein binding (PPB) via ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples. Experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This data set is a subset of experimental data containing samples for 3 test analytes/compounds.
fup_uc_L0A level-0 data.frame with 240 rows and 17 variables:
CompoundName of the test analyte/compound
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard - CCD)
Lab.Compound.IDCompound as described in the laboratory
DateDate the sample was added to the MS analyzer
SampleSample description used in the laboratory
TypeType of UC sample, annotated by the laboratory
Compound.ConcExpected (or nominal) concentration of analyte (for calibration curve)
Peak.AreaPeak area of analyte (target compound)
ISTD.Peak.AreaPeak area of internal standard (ISTD) compound (pixels)
ISTD.NameName of the internal standard (ISTD) analyte/compound
Analysis.ParamsColumn contains the retention time
Level0.FileName of the laboratory data file from which the level-0 sample data was extracted
Level0.SheetName of the Excel workbook 'sheet' from which the level-0 sample data was extracted
Sample.TextAdditional notes on the sample
Sample.TypeType of UC sample in invitroTKstats package annotations
Dilution.FactorNumber of times the sample was diluted
ReplicateIdentifier for repeated measurements of one sample of a compound
howard2010plasmainvitroTKstats
smeltz2023plasmainvitroTKstats