The arguments given to JAGS for the tested compound during level-4 processing of mass spectrometry measurements of plasma protein binding (PPB) via ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples. Experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This list is overwritten for each tested compound. Therefore, only contains arguments given to JAGS for the last tested compound.
fup_uc_PREJAGSA named list with 10 elements:
Num.calUnique number of Calibration values for the tested compound
Num.obsTotal number of observations for the tested compound
Response.obsResponse of all samples for the tested compound
obs.concIndices of the Test.Compound.Conc values that corresponds to all samples' Test.Compound.Conc for the tested compound.
obs.calIndices of the unique Calibration values that corresponds to all samples' Calibration for the tested compound.
ConcTest.Compound.Conc of the "CC" sample types + three placeholder concentrations ("T1", "T5", "AF") per Biological.Replicates series
Num.cc.obsNumber of "CC" sample types for the tested compound
Num.seriesUnique number of Biological.Replicates series
Dilution.FactorDilution.Factor of all samples for the tested compound (number of times the sample was diluted)
Test.Nominal.ConcUnique Test.Nominal.Conc values (expected initial concentration) of all samples for the tested compound
howard2010plasmainvitroTKstats
smeltz2023plasmainvitroTKstats