- FILENAME
(Character) A string used to identify outputs of the function call.
(Default to "MYDATA")
- level0.catalog
A data frame describing which columns of which sheets
in which Excel files contain MS data for analysis. See details for full
explanation.
- file.col
(Character) Column name containing level-0 file names
to pull data from.
- sheet
(Character) Excel file sheet name/identifier containing
level-0 where data is to be pulled from. (Defaults to `NULL`.) (Note: Single
entry only, use only if all files have the same sheet identifier for
level-0 data.)
- sheet.col
(Character) Catalog column name containing `sheet`
information. (Default to "Sheet")
- skip.rows
(Numeric) Number of rows to skip when extracting level-0
data from the specified Excel file(s). (Defaults to `NULL`.) (Note: Single
entry only, use only if all files need to skip the same number of rows
for extracting level-0 data.)
- skip.rows.col
(Character) Catalog column name containing `skip.rows`
information. (Default to "Skip.Rows")
- num.rows
(Numeric) Number of rows to pull when extracting level-0
data from the specified Excel file(s). (Defaults to `NULL`.) (Note: Single
entry only, use only if all files need to pull the same number of rows for
extracting level-0 data.)
- num.rows.col
(Character) Catalog column name containing `num.rows`
information. (Default to `NULL`)
- date
(Character) Date of laboratory measurements. Typical format
"MMDDYY" ("MM" = 2 digit month, "DD" = 2 digit day, and "YY" = 2 digit year).
(Defaults to `NULL`.) (Note: Single entry only, use only if all files have
the same laboratory measurement date.)
- date.col
(Character) Catalog column name containing `date`
information. (Defaults to "Date")
- compound.col
(Character) Catalog column name containing `compound`
information. (Defaults to "Chemical.ID")
- istd.col
(Character) Catalog column name containing `istd` information,
or the MS peak area for the internal standard. (Defaults to "ISTD")
- col.names.loc
(Numeric) Row location of data column names. (Defaults to
'NULL'.) (Note: Single entry only, use only if all files have column names
in the same row location, typically the first row.)
- col.names.loc.col
(Character) Catalog column name containing `col.names.loc`
information. (Defaults to "Col.Names.Loc")
- sample.colname
(Character) Column name of level-0 data containing
sample information. (Defaults to `NULL`.) (Note: Single entry only, use only
if all files use the same column name for sample names when extracting
level-0 data.)
- sample.colname.col
(Character) Catalog column name containing
`sample.colname` information. (Defaults to "Sample.ColName")
- type.colname
(Character) Column name of the level-0 data containing
the type of sample. (Defaults to `NULL`.) (Note: Single entry only, use
only if all files use the same column name for sample type information
when extracting level-0 data.)
- type.colname.col
(Character) Catalog column name containing
`type.colname` information. (Defaults to "Type".)
- peak.colname
(Character) Column name of the level-0 data containing
the analyte Mass Spectrometry peak area. (Defaults to `NULL`.)
(Note: Single entry only, use only if all files use the same column name
for analyte peak area information when extracting level-0 data.)
- peak.colname.col
(Character) Catalog column name containing
`peak.colname` information. (Defaults to "Peak.ColName")
- istd.peak.colname
(Character) Column name of the level-0 data
containing the internal standard Mass Spectrometry peak area. (Note: Single
entry only, use only if all files use the same column name for internal
standard MS peak area information when extracting level-0 data.)
- istd.peak.colname.col
(Character) Catalog column name containing
`istd.peak.colname` information. (Defaults to "ISTD.Peak.ColName")
- conc.colname
(Character) Column name of the level-0 data containing
intended concentrations for calibration curves. (Defaults to `NULL`.)
(Note: Single entry only, use only if all files use the same column name
for intended concentration information when extracting level-0 data.)
- conc.colname.col
(Character) Catalog column name containing
`conc.colname` information. (Defaults to "Conc.ColName")
- analysis.param.colname
(Character) Column name of the level-0 data
containing Mass Spectrometry instrument parameters for the analyte.
(Defaults to `NULL`.) (Note: Single entry only, use only if all files use
the same column name for analysis parameter information when extracting
level-0 data.)
- analysis.param.colname.col
(Character) Catalog column name containing
`analysis.param.colname` information. (Defaults to "AnalysisParam.ColName")
- additional.colnames
Additional columns from the level-0 data files to
pull information from when extracting level-0 data and include in the
compiled level-0 returned from `merge_level0`. (Defaults to `NULL`.)
- additional.colname.cols
Catalog column name(s) containing
`additional.colnames` information, (Defaults to `NULL`.)
- chem.ids
(Data frame) A data frame containing basic chemical
identification information for tested chemicals.
- chem.lab.id.col
(Character) Column in `chem.ids` containing
the compound/chemical identifier used by the laboratory in level-0 measured
data. (Defaults to "Chem.Lab.ID")
- chem.name.col
(Character) `chem.ids` column name containing the
"standard" chemical name to use for annotation of the compiled level-0
returned from `merge_level0`. (Defaults to "Compound")
- chem.dtxsid.col
(Character) `chem.ids` column name containing EPA's
DSSTox Structure ID (http://comptox.epa.gov/dashboard)
(Defaults to "DTXSID")
- catalog.out
(Logical) When set to TRUE, the data frame
specified in level0.catalog will be exported to the user's per-session
temporary directory or OUTPUT.DIR (if specified) as a .tsv file.
(Defaults to FALSE.)
- output.res
(Logical) When set to TRUE, the result
table (level-0) will be exported to the user's per-session temporary directory
or OUTPUT.DIR (if specified) as a .tsv file. (Defaults to FALSE.)
- INPUT.DIR
(Character) Path to the directory where the Excel files
with level-0 data exist. If not specified, looking for the files
in the current working directory. (Defaults to NULL.)
- OUTPUT.DIR
(Character) Path to the directory to save the output file.
If NULL, the output file will be saved to the user's per-session temporary
directory. (Defaults to NULL.)
- verbose
(logical) Indicate whether printed statements should be shown.
(Default is TRUE.)