Learn R Programming

invitroTKstats (version 0.0.14)

plot_clint: Plot Mass Spectrometry Responses from Measurements of Intrinsic Hepatic Clearance

Description

This function generates a response-versus-time plot of mass spectrometry (MS) responses collected from measurements of intrinsic hepatic clearance for a chemical. Responses from different measurements/calibrations are labeled with different colors, and responses from various sample types are labeled with different shapes.

Usage

plot_clint(level2, dtxsid, color.palette = "viridis")

Value

ggplot2

A figure of mass spectrometry responses over time for various sample types.

Arguments

level2

(Data Frame) A data frame containing level-2 data with a measure of chemical clearance over time when incubated with suspended hepatocytes.

dtxsid

(Character) EPA's DSSTox Structure ID for the chemical to be plotted.

color.palette

(Character) A character string indicating which viridis R package color map option to use. (Defaults to "viridis".)

Author

John Wambaugh

Details

The function requires "level-2" data for plotting. Level-2 data is level-1, data formatted with the format_clint function, and curated with a verification column. "Y" in the verification column indicates the data row is valid for plotting.

Examples

Run this code
## Load example level-2 data 
level2 <- invitroTKstats::clint_L2
plot_clint(level2, dtxsid = "DTXSID1021116")

Run the code above in your browser using DataLab