.check_all_miss_cols: Check if all the data is missing for specified columns.
Description
This function checks for whether any of the specified columns
are missing all of their data, either `NA` and/or `NULL`.
Usage
.check_all_miss_cols(data, req.cols)
Arguments
- data
Data frame to check.
- req.cols
Column names that should be checked for whether all data is missing.