.check_num_cols: Check the numeric columns are correctly of numeric class.
Description
Check the numeric columns are correctly of numeric class.
Usage
.check_num_cols(data, num.cols)
Arguments
- data
Data frame to check.
- num.cols
Column names that should be of the numeric class.