Builds a list of arguments required for JAGS from subset of level-2 data frame. The list is used as an argument to JAGS during level-4 processing.
build_mydata_fup_red(this.data, Physiological.Protein.Conc)A named list to be passed into the Bayesian model.
(Data Frame) Subset of data containing all observations of one test compound.
(Numeric) The assumed physiological protein concentration for plasma protein binding calculations.