## Load example level-2 data
level2 <- invitroTKstats::clint_L2
## scenario 1:
## input level-2 data from the R session and do not export the result table
level3 <- calc_clint_point(data.in = level2, output.res = FALSE)
## scenario 2:
## import level-2 data from a 'tsv' file and export the result table to
## same location as INPUT.DIR
if (FALSE) {
## Refer to sample_verification help file for how to export level-2 data to a directory.
## Unless a different path is specified in OUTPUT.DIR,
## the result table will be saved to the directory specified in INPUT.DIR.
## Will need to replace FILENAME and INPUT.DIR with name prefix and location of level-2 'tsv'.
level3 <- calc_clint_point(# e.g. replace with "Examples" from "Examples-Clint-Level2.tsv"
FILENAME="",
INPUT.DIR = "",
output.res = TRUE)
}
## scenario 3:
## input level-2 data from the R session and export the result table to the
## user's temporary directory
## Will need to replace FILENAME with desired level-2 filename prefix.
if (FALSE) {
level3 <- calc_clint_point(# e.g. replace with "MYDATA"
FILENAME = "",
data.in = level2,
output.res = TRUE)
# To delete, use the following code. For more details, see the link in the
# "Details" section.
file.remove(list.files(tempdir(), full.names = TRUE,
pattern = "-Clint-Level3.tsv"))
}
Run the code above in your browser using DataLab