check_catalog: Function to Check Level 0 Data Catalog
Description
This function is meant to check whether the catalog file is in the anticipated
format with required information.
Usage
check_catalog(catalog, verbose = TRUE)
Value
(No value returned) Text output indicating whether the level-0 data
catalog meets all the necessary requirements in order to auto-extract
data from the various source files, or output indicating necessary
updates to the data catalog. (NOTE: Nothing is returned if verbose is
set to FALSE.)
Arguments
catalog
The catalog to be checked, format `data.frame`.
verbose
(logical) Indicate whether printed statements should be shown.
(Default is TRUE.)