Mass Spectrometry measurements of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocytes. Chemicals were per- and poly-fluorinated alkyl substance (PFAS) samples. The experiments were led by Dr.s Marci Smeltz and Barbara Wetmore smeltz2023plasmainvitroTKstats. This data set is a subset of experimental data containing samples for 3 test analytes/compounds.
clint_L3A level-3 data.frame with 3 rows and 13 variables:
Compound.NameName of the test analyte/compound
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard - CCD)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration -- usually the date
ClintIntrinsic hepatic clearance
Clint.pValuep-value of estimated Clint value
FitTest nominal concentrations
AICAkaike Information Criterion of the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM
Clint.10Intrinsinc hepatic clearance at 10 uM
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
shibata2002predictioninvitroTKstats
smeltz2023plasmainvitroTKstats